==> haskell-yesod-auth-1.6.8-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.6.8
id: yesod-auth-1.6.8-CFOtzSE8CXaDhsWSrXhHiv
key: yesod-auth-1.6.8-CFOtzSE8CXaDhsWSrXhHiv
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
abi: af4c404ddb4438a5de8a0a06e20f1184
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore
hidden-modules: Yesod.Auth.Routes
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-auth-1.6.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-auth-1.6.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-auth-1.6.8
hs-libraries: HSyesod-auth-1.6.8-CFOtzSE8CXaDhsWSrXhHiv
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    authenticate-1.3.4-DgQRwMl8LkDs6yWQ2wlOw base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    conduit-1.3.1.1-CfM5hRP1Ia6GpnibXcmH9G
    conduit-extra-1.3.4-ApR2ZiAyfO54oTAYFYfASb containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    email-validate-2.3.2.11-ERGbRnZUwr48XHt00rn7dV
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    http-client-0.6.4-73LSh37vIvj1AryXK8OuVy
    http-client-tls-0.3.5.3-LHtZCdKJkqrHjfPnvP0juz
    http-conduit-2.3.7.1-G2w7vWPk1V4DF7fe0f7sBo
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    nonce-1.0.7-DJ2T80Bc42GKwLZg9SxSiq
    persistent-2.10.1-7pXWa2dlvJy4zQ0L3Ek9xr
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.21-2LOxZglsNEK6waTgvreNvH template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    yesod-core-1.6.16.1-3ZUz3YF8YXeKlUSD880OPl
    yesod-form-1.6.7-GuYG2AWwyxpJE0XK1A88ar
    yesod-persistent-1.6.0.2-2TXTtU9jfQBK9v4aKHmNan
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-auth-1.6.8-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.6.8
id: yesod-auth-1.6.8-7eylIXvDAYc5iJlYT6RO99
key: yesod-auth-1.6.8-7eylIXvDAYc5iJlYT6RO99
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
abi: 8535a1382a11061429885e18513f8cf8
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore
hidden-modules: Yesod.Auth.Routes
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-auth-1.6.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-auth-1.6.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-auth-1.6.8
hs-libraries: HSyesod-auth-1.6.8-7eylIXvDAYc5iJlYT6RO99
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    authenticate-1.3.4-4EwAlKF9JuoV1fckec3Bp base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.2-LFnllGMPezqEutot32d3pA
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    conduit-1.3.1.1-4WoHy8vBnBFBnZww6g0450
    conduit-extra-1.3.4-L7lgAb062eI3vVnzXOYpfp containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    email-validate-2.3.2.12-I2BUPjtawIkFUV6J9ZIdeJ
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    http-client-0.6.4-73LSh37vIvj1AryXK8OuVy
    http-client-tls-0.3.5.3-4PGEPic6cDg9YG1xYBLM0k
    http-conduit-2.3.7.3-1uFMdKvtNTiH4fppk0p7LP
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    nonce-1.0.7-DJ2T80Bc42GKwLZg9SxSiq
    persistent-2.10.1-BbK0JqpbpfkDXTNL7U3y5F
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.22-4E8w3hvU79w3ueBJcyXWIC template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    yesod-core-1.6.16.1-340F7TgpBKe1GJVGtKqSjj
    yesod-form-1.6.7-E5QfzWo9E82AZYQQVcnXoT
    yesod-persistent-1.6.0.2-7kzPfcwyqxY7IJF7KjZqwQ
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
